Learn R Programming

catregs (version 1.3)

rubins.rule: Aggregate Standard Errors using Rubin's Rule.

Description

The function takes a vector of standard error estimates and it pools them using Rubin's rule.

Usage

rubins.rule(std.errors)

Value

r.r.std.error

The aggregated standard error.

Arguments

std.errors

A vector of standard errors to be aggregated using Rubin's rule.

Author

David Melamed

References

Rubin, Donald B. 2004. Multiple Imputation for Nonresponse in Surveys. Vol. 81. John Wiley & Sons.